from logging import DEBUG, Logger
from logging.handlers import QueueHandler, RotatingFileHandler
from typing import Any

from rich.text import Text
from rich.theme import Theme

from .._console_junk import ConsoleBuffering, ConsoleHandler
from ._base_logger import BaseLogger
from ._sub_logger import SubConsoleLogger

class ConsoleLogger(Logger, BaseLogger):

    name: str
    level: int
    file: bool
    queue_handler: QueueHandler
    buffer_handler: ConsoleBuffering
    console_handler: ConsoleHandler
    file_handler: RotatingFileHandler
    sub_logger: dict[str, "SubConsoleLogger[ConsoleLogger]"]

    def __init__(
        self,
        theme: Theme | None = None,
        name: str = "ConsoleLogger",
        level: int = DEBUG,
        disabled: bool = True,
        queue_handler: bool = False,
        buffering: bool = False,
        file: bool = False,
        console: bool = True,
        style_disabled: bool = False,
        logger_mode: bool = True,
        *args,
        **kwargs,
    ) -> None:
        """
        A general purpose console logger that that by default is a wrapper around both Rich and Python's logging module.

        Args:
            theme (Theme | None): The theme for the logger.
            name (str): The name of the logger.
            level (int): The logging level.
            disabled (bool): Whether the logger is disabled.
            queue_handler (bool): Whether to use a queue handler.
            buffering (bool): Whether to use buffering.
            file (bool): Whether to log to a file.
            style_disabled (bool): Whether to disable styling.
            logger_mode (bool): Whether to enable logger mode.
        """
    # fmt: off
    def debug(self, msg: object, *args, **kwargs: Any) -> None: ...
    def info(self, msg: object, *args, **kwargs: Any) -> None: ...
    def warning(self, msg: object, *args, **kwargs: Any) -> None: ...
    def error(self, msg: object, *args, **kwargs: Any) -> None: ...
    def success(self, msg: str, *args, **kwargs: Any) -> None: ...
    def failure(self, msg: str, *args, **kwargs: Any) -> None: ...
    def verbose(self, msg: str, *args, **kwargs: Any) -> None: ...
    def set_base_level(self, level: int) -> None: ...
    def input(self, msg: str, style: str = "info") -> str: ...
    def trigger_buffer_flush(self) -> str | Text: ...
    def print(self, msg: object, end: str="\n", exc_info=None, extra: dict | None = None, *args, **kwargs) -> None | str: ...
    def exit(self) -> None: ...
